==> zio-aws-kms_2.13-5.17.155.2-sources.jar: zio/aws/kms/model/GenerateDataKeyResponse.scala <==
package zio.aws.kms.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.kms.model.primitives.{KeyIdType, PlaintextType, CiphertextType}
import scala.jdk.CollectionConverters._
final case class GenerateDataKeyResponse(
    ciphertextBlob: Option[CiphertextType] = None,
    plaintext: Option[PlaintextType] = None,
    keyId: Option[KeyIdType] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kms.model.GenerateDataKeyResponse = {
    import GenerateDataKeyResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kms.model.GenerateDataKeyResponse
      .builder()
      .optionallyWith(
        ciphertextBlob.map(value =>
          software.amazon.awssdk.core.SdkBytes
            .fromByteArrayUnsafe(value.toArray[Byte])
        )
      )(_.ciphertextBlob)
      .optionallyWith(
        plaintext.map(value =>
          software.amazon.awssdk.core.SdkBytes
            .fromByteArrayUnsafe(value.toArray[Byte])
        )
      )(_.plaintext)
      .optionallyWith(
        keyId.map(value => KeyIdType.unwrap(value): java.lang.String)
      )(_.keyId)
      .build()
  }
  def asReadOnly: zio.aws.kms.model.GenerateDataKeyResponse.ReadOnly =
    zio.aws.kms.model.GenerateDataKeyResponse.wrap(buildAwsValue())
}
object GenerateDataKeyResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kms.model.GenerateDataKeyResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kms.model.GenerateDataKeyResponse =
      zio.aws.kms.model.GenerateDataKeyResponse(
        ciphertextBlob.map(value => value),
        plaintext.map(value => value),
        keyId.map(value => value)
      )
    def ciphertextBlob: Option[CiphertextType]
    def plaintext: Option[PlaintextType]
    def keyId: Option[KeyIdType]
    def getCiphertextBlob: ZIO[Any, AwsError, CiphertextType] =
      AwsError.unwrapOptionField("ciphertextBlob", ciphertextBlob)
    def getPlaintext: ZIO[Any, AwsError, PlaintextType] =
      AwsError.unwrapOptionField("plaintext", plaintext)
    def getKeyId: ZIO[Any, AwsError, KeyIdType] =
      AwsError.unwrapOptionField("keyId", keyId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kms.model.GenerateDataKeyResponse
  ) extends zio.aws.kms.model.GenerateDataKeyResponse.ReadOnly {
    override val ciphertextBlob: Option[CiphertextType] = scala
      .Option(impl.ciphertextBlob())
      .map(value =>
        zio.aws.kms.model.primitives
          .CiphertextType(zio.Chunk.fromArray(value.asByteArrayUnsafe()))
      )
    override val plaintext: Option[PlaintextType] = scala
      .Option(impl.plaintext())
      .map(value =>
        zio.aws.kms.model.primitives
          .PlaintextType(zio.Chunk.fromArray(value.asByteArrayUnsafe()))
      )
    override val keyId: Option[KeyIdType] = scala
      .Option(impl.keyId())
      .map(value => zio.aws.kms.model.primitives.KeyIdType(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.kms.model.GenerateDataKeyResponse
  ): zio.aws.kms.model.GenerateDataKeyResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-kms_2.13-6.20.47.1-sources.jar: zio/aws/kms/model/GenerateDataKeyResponse.scala <==
package zio.aws.kms.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.kms.model.primitives.{KeyIdType, PlaintextType, CiphertextType}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GenerateDataKeyResponse(
    ciphertextBlob: Optional[CiphertextType] = Optional.Absent,
    plaintext: Optional[PlaintextType] = Optional.Absent,
    keyId: Optional[KeyIdType] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kms.model.GenerateDataKeyResponse = {
    import GenerateDataKeyResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kms.model.GenerateDataKeyResponse
      .builder()
      .optionallyWith(
        ciphertextBlob.map(value =>
          software.amazon.awssdk.core.SdkBytes
            .fromByteArrayUnsafe(value.toArray[Byte])
        )
      )(_.ciphertextBlob)
      .optionallyWith(
        plaintext.map(value =>
          software.amazon.awssdk.core.SdkBytes
            .fromByteArrayUnsafe(value.toArray[Byte])
        )
      )(_.plaintext)
      .optionallyWith(
        keyId.map(value => KeyIdType.unwrap(value): java.lang.String)
      )(_.keyId)
      .build()
  }
  def asReadOnly: zio.aws.kms.model.GenerateDataKeyResponse.ReadOnly =
    zio.aws.kms.model.GenerateDataKeyResponse.wrap(buildAwsValue())
}
object GenerateDataKeyResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kms.model.GenerateDataKeyResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kms.model.GenerateDataKeyResponse =
      zio.aws.kms.model.GenerateDataKeyResponse(
        ciphertextBlob.map(value => value),
        plaintext.map(value => value),
        keyId.map(value => value)
      )
    def ciphertextBlob: Optional[CiphertextType]
    def plaintext: Optional[PlaintextType]
    def keyId: Optional[KeyIdType]
    def getCiphertextBlob: ZIO[Any, AwsError, CiphertextType] =
      AwsError.unwrapOptionField("ciphertextBlob", ciphertextBlob)
    def getPlaintext: ZIO[Any, AwsError, PlaintextType] =
      AwsError.unwrapOptionField("plaintext", plaintext)
    def getKeyId: ZIO[Any, AwsError, KeyIdType] =
      AwsError.unwrapOptionField("keyId", keyId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kms.model.GenerateDataKeyResponse
  ) extends zio.aws.kms.model.GenerateDataKeyResponse.ReadOnly {
    override val ciphertextBlob: Optional[CiphertextType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.ciphertextBlob())
        .map(value =>
          zio.aws.kms.model.primitives
            .CiphertextType(zio.Chunk.fromArray(value.asByteArrayUnsafe()))
        )
    override val plaintext: Optional[PlaintextType] = zio.aws.core.internal
      .optionalFromNullable(impl.plaintext())
      .map(value =>
        zio.aws.kms.model.primitives
          .PlaintextType(zio.Chunk.fromArray(value.asByteArrayUnsafe()))
      )
    override val keyId: Optional[KeyIdType] = zio.aws.core.internal
      .optionalFromNullable(impl.keyId())
      .map(value => zio.aws.kms.model.primitives.KeyIdType(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.kms.model.GenerateDataKeyResponse
  ): zio.aws.kms.model.GenerateDataKeyResponse.ReadOnly = new Wrapper(impl)
}
